@@ -54,14 +54,14 @@ class Settings(object):
         self._raw_settings = settings
         self._configurables = []
 
-    def get(self, section, name, default=NOT_PROVIDED):
+    def get(self, section, name, default=NOT_PROVIDED, type=lambda x: x):
         """Return the value identified by section and name."""
         try:
-            return self._raw_settings[section][name]
+            return type(self._raw_settings[section][name])
         except KeyError:
             if default == NOT_PROVIDED:
                 raise
-            return default
+            return type(default)
 
     def setdefault(self, section, name, value):
         self._raw_settings[section].setdefault(name, value)
